<?php

// No direct access.
defined('_JEXEC') or die();

// Load language file for plugin frontend.
$lang = JFactory::getLanguage();
$lang->load('plg_content_pdf_embed', JPATH_ADMINISTRATOR);

/**
 * Class for Plg_pdf_embed
 *
 * @package  PdfEmbed
 * @since    1.0
 */
class PlgContentPdf_Embed extends JPlugin
{
	/**
	 * takes the parameter for pdf
	 *
	 * @param   string   $context  The context of the content being passed to the plugin.
	 *
	 * @param   object   $row      The article object.  Note $article->text is also available
	 * @param   object   $params   The article params
	 * @param   integer  $page     The 'page' number
	 *
	 * @return   html for the pdf
	 *
	 * @since   1.0
	 */
	public function onContentPrepare($context, $row, $params, $page = 0)
	{
	    $this->_secure_option = $this->params->get('secure_option',1);
		$document = JFactory::getDocument();
		$document->addStyleSheet(JURI::base() . "/plugins/content/pdf_embed/assets/css/style.css");

		$regex  = "#{pdf[\=|\s]?(.+)}#s";
		$regex1 = '/{(pdf=)\s*(.*?)}/i';

		// Find all instances of mambot and put in $matches
		preg_match_all($regex1, $row->text, $matches);

		// Number of mambots
		$count = count($matches[0]);

		for ($i = 0; $i < $count; $i++)
		{
			$r  = str_replace('{pdf=', '', $matches[0][$i]);
			$r  = str_replace('}', '', $r);
			$ex = explode('|', $r);
			$ploc = $ex[0];
			$w   = $ex[1];
			$isWidthInPer = strpos($w, '%');
			$isWidthInPix = strpos($w, 'px');

			// Check if width is in percentage and pixel
			if (!$isWidthInPer && !$isWidthInPix)
			{
				$w = $w . 'px';
			}

			$h = $ex[2];
			$isHeightInPer = strpos($h, '%');
			$isHeightInPix = strpos($h, 'px');

			// Check if width is in percentage and pixel
			if (!$isHeightInPer && !$isHeightInPix)
			{
				$h = $h . 'px';
			}

			if (isset($ex[3]))
			{
				$viewer    = 'pdfjs';
				$replace   = $this->plg_pdfembed_replacer($ploc, $w, $h, $viewer);
				$row->text = str_replace('{pdf=' . $ex[0] . '|' . $ex[1] . '|' . $ex[2] . '|' . $ex[3] . '}', $replace, $row->text);
			}
			else
			{
				$viewer    = $this->params->def('viewer', 'pdfjs');
				$replace   = $this->plg_pdfembed_replacer($ploc, $w, $h, $viewer);
				$row->text = str_replace('{pdf=' . $ex[0] . '|' . $ex[1] . '|' . $ex[2] . '}', $replace, $row->text);
			}
		}

		return true;
	}

	/**
	 * Gets  the pdf in site article
	 *
	 * @param   string   $ploc    Takes the address of pdf location
	 * @param   integer  $w       Takes width of pdf
	 * @param   integer  $h       Takes height of pdf
	 * @param   string   $viewer  Takes the view user want to use
	 *
	 * @return  string in the article
	 */
	public function plg_pdfembed_replacer($ploc, $w, $h, $viewer)
	{
		$ploc = trim($ploc);

		switch ($viewer)
		{
			case "google":
				$ploc = urlencode($ploc);

				return '<div class ="">
							<iframe src="https://docs.google.com/gview?url=' . $ploc . '&embedded=true" style="width:' . $w . '; height:' . $h . ';" frameborder="0">
							</iframe>
						</div>';

			case "pdfjs":
				$ploc 	= urlencode($ploc);
				$pdfUrl = JUri::root(true) . '/plugins/content/pdf_embed/assets/viewer/pdfjs/web/viewer.html?file=' . $ploc;

				if($this->_secure_option == 1){
				return '<div class ="">
							<iframe src="' . $pdfUrl . '" style="width:' . $w . '; height:' . $h . ';" frameborder="0">
							</iframe>
						</div>
						<script type="text/javascript">
							var isNS = (navigator.appName == "Netscape") ? 1 : 0;

						    if(navigator.appName == "Netscape") document.captureEvents(Event.MOUSEDOWN||Event.MOUSEUP);

						    function mischandler(){
						    return false;
						    }

						    function mousehandler(e){
						    var myevent = (isNS) ? e : event;
						    var eventbutton = (isNS) ? myevent.which : myevent.button;
						    if((eventbutton==2)||(eventbutton==3)) return false;
						    }
						    document.oncontextmenu = mischandler;
						    document.onmousedown = mousehandler;
						    document.onmouseup = mousehandler;
						    var isCtrl = false;
						    document.onkeyup=function(e)
						    {
						    if(e.which == 17)
						    isCtrl=false;
						    }

						    document.onkeydown=function(e)
						    {
						    if(e.which == 17)
						    isCtrl=true;
						    if(((e.which == 73) || (e.which == 105) || (e.which == 85) || (e.which == 117) || (e.which == 65) || (e.which == 97) || (e.which == 67) || (e.which == 99)) && isCtrl == true)
						    {
						    // alert(‘Keyboard shortcuts are cool!’);
						    return false;
						    }

						    }
						    document.onkeydown = function (event) {
							    event = event || window.event;//Get event
							    if (event.ctrlKey) {
							        var c = event.which || event.keyCode;//Get key code
							        switch (c) {
							            case 83://Block Ctrl+S
							                event.preventDefault();     
							                event.stopPropagation();
							            break;
							        }
							    }
							    if (event.keyCode == 123) {
						           //alert("No F-12");
						            return false;
						        }
							};
							window.addEventListener("keydown", function(event) {
							    if (event.keyCode === 80 && (event.ctrlKey || event.metaKey) && !event.altKey && (!event.shiftKey || window.chrome || window.opera)) {
							        event.preventDefault();
							        if (event.stopImmediatePropagation) {
							            event.stopImmediatePropagation();
							        } else {
							            event.stopPropagation();
							        }
							        return;
							        }
							}, true);
						</script>';
				}
				else {
				    return '<div class ="">
							<iframe src="' . $pdfUrl . '" style="width:' . $w . '; height:' . $h . ';" frameborder="0">
							</iframe>
						</div>';
				}

			default:
				return '<div class ="embed-container native-embed-container">
				<embed src="' . $ploc . '" style="width:' . $w . '; height:' . $h . ';" frameborder="0"/></div>';
		}
	}
}
?>